@@ -1,7 +1,7 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.40_001'; # TRIAL
+$Net::Stripe::VERSION = '0.40_002'; # TRIAL
 
-$Net::Stripe::VERSION = '0.40001';use Moose;
+$Net::Stripe::VERSION = '0.40002';use Moose;
 use Class::Load;
 use Type::Tiny 1.008004;
 use Kavorka;
@@ -293,14 +293,19 @@ Cards: {
         StripeTokenId :$source?,
     ) {
 
-die "post_card requires card or source" unless defined( $card ) || defined( $source );
+        die Net::Stripe::Error->new(
+            type => "post_card error",
+            message => "One of parameters 'source' or 'card' is required.",
+        ) unless defined( $card ) || defined( $source );
 
         my $customer_id = ref( $customer ) ? $customer->id : $customer;
+
         if ( defined( $card ) ) {
             # card here is either Net::Stripe::Token or StripeTokenId
             my $token_id = ref( $card ) ? $card->id : $card;
             return $self->_post("customers/$customer_id/cards", {card=> $token_id});
         }
+
         if ( defined( $source ) ) {
             return $self->_post("customers/$customer_id/cards", { source=> $source });
         }
@@ -1119,7 +1124,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.40_001
+version 0.40_002
 
 =head1 SYNOPSIS
 
