@@ -1,7 +1,7 @@
 package Net::Stripe::Source;
-$Net::Stripe::Source::VERSION = '0.40_001'; # TRIAL
+$Net::Stripe::Source::VERSION = '0.40_002'; # TRIAL
 
-$Net::Stripe::Source::VERSION = '0.40001';use Moose;
+$Net::Stripe::Source::VERSION = '0.40002';use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -12,7 +12,7 @@ has 'amount'                => (is => 'ro', isa => 'Maybe[Int]');
 has 'currency'              => (is => 'ro', isa => 'Maybe[Str]');
 has 'flow'                  => (is => 'ro', isa => 'Maybe[StripeSourceFlow]');
 has 'mandate'               => (is => 'ro', isa => 'Maybe[HashRef]');
-has 'metadata'              => (is => 'ro', isa => 'Maybe[HashRef|EmptyStr]');
+has 'metadata'              => (is => 'ro', isa => 'Maybe[HashRef[Str]|EmptyStr]');
 has 'owner'                 => (is => 'ro', isa => 'Maybe[HashRef]');
 has 'receiver'              => (is => 'ro', isa => 'Maybe[HashRef]');
 has 'redirect'              => (is => 'ro', isa => 'Maybe[HashRef]');
@@ -49,7 +49,7 @@ Net::Stripe::Source - represent a Source object from Stripe
 
 =head1 VERSION
 
-version 0.40_001
+version 0.40_002
 
 =head1 ATTRIBUTES
 
@@ -117,7 +117,7 @@ Type: Maybe[HashRef]
 
 Reader: metadata
 
-Type: Maybe[EmptyStr|HashRef]
+Type: Maybe[EmptyStr|HashRef[Str]]
 
 =head2 owner
 
